\name{setx}

\alias{setx}

\title{Setting Explanatory Variable Values}

\description{ The \code{setx} command uses the variables identified in
  the \code{formula} generated by \code{zelig} and sets the values of
  the explanatory variables to the selected values.  Use \code{setx}
  after \code{zelig} and before \code{sim} to simulate quantities of
  interest.  }

\usage{
x.out <- setx(object, fn = mean, data = NULL, cond = FALSE, \dots)
}

\arguments{
  \item{object}{the saved output from \code{\link{zelig}}. }
  \item{fn}{a function applied to all non-factor variables.
    The default function is mean. The default value for factor
    variables corresponds to the value of the greatest mode. When more
    than one such mode exists, the smallest value in \code{Levels}
    is selected.  Setting \code{fn = median} changes the value for the
    non-factor variables to their medians, and factor variables may be
    set by specifying exact variables. }
  \item{data}{a new data frame used to set the values of
    explanatory variables. If \code{data = NULL} (the default), the
    data frame called in \code{zelig} is used. }
  \item{cond}{a logical value indicating whether unconditional
    (default) or conditional (choose \code{cond = TRUE}) prediction
    should be performed.  If you choose \code{cond = TRUE}, \code{setx}
    will ignore the arguments in \code{fn} and \code{\dots}. }  
  \item{\dots}{user-defined values of specific variables
    overwriting the default values set by the function \code{fn}.  For
    example, adding \code{var1 = mean(data\$var1)} or \code{x1 = 12}
    explicitly sets the value of \code{x1} to 12.  In addition, you may
    specify one explanatory variable as a range of values, creating one
    observation for every unique value in the range of values. }
}

\values{
  For unconditional prediction, \code{x.out} is a model matrix based
  on the specified values for the explanatory variables.  For multiple
  analyses (i.e., when choosing the \code{by} option in \code{\link{zelig}},
  \code{setx} returns the selected values calculated over the entire
  data frame.  If you wish to calculate values over just one subset of
  the data frame, the 5th subset for example, you may use:  
\begin{verbatim}
x.out <- setx(z.out[[5]])
\end{verbatim} 

For conditional prediction, \code{x.out} includes the model matrix
  and the dependent variables.  For multiple analyses (when choosing
  the \code{by} option in \code{zelig}), \code{setx} returns the
  observed explanatory variables in each subset.
}

\example{
# Unconditional prediction:
data(turnout)
z.out <- zelig(vote ~ race + educate, model = "logit", data = turnout)
x.out <- setx(z.out)
s.out <- sim(z.out, x = x.out)
plot(s.out1)

# Conditional prediction:  
data(lalonde)
match.out <- matchit(treat ~ age + educ + black + hispan + married + 
                     nodegree + re74 + re75, data = lalonde)
z.out <- zelig(re78 ~ pscore, data = match.data(match, "control"), 
               model = "ls")
x.out <- setx(z.out, data = match.data(match, "treat"), cond = TRUE)
s.out <- sim(z.out, x = x.out)

# Conditional prediction with multiple analyses:  
data(turnout)
z.out <- zelig(vote ~ age + educate + income, by = "race",
               data = turnout, model = "probit")

# Calculate the ATE for race == "white":
x.white <- setx(z.out$others, data = turnout[turnout$race == "white",], 
                cond = TRUE)
s.others <- sim(z.out$others, x = x.white)

Calculate the ATE for the race == "others":
x.others <- setx(z.out$white, data = turnout[turnout$race == "others",], 
                  cond = TRUE)
s.others <- sim(z.out$white, x = x.others)
}

\seealso{ The full Zelig manual may be accessed online at
  \url{http://gking.harvard.edu/zelig}.  }

\author{
  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Olivia Lau <\email{olau@fas.harvard.edu}>
}

\keyword{file}
